.. PREP Quickstarts master file, created by
   sphinx-quickstart on Tue Jul  3 12:03:15 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _prep-quickstart-tutorials:

PREP Quickstart Tutorials
=========================

Sometimes all one needs to start using Sage in a field is a little help.
These "Quickstart" tutorials are designed to get you up and running in
one of these fields with a minimum of fuss and muss.

The assumed background in most of these is the first several tutorials
in this set of documents.  Similarly, keep in mind that these documents
are *concise*; the next step from each of them is really the Sage
reference manual.

Finally, the last tutorial is a special one introducing the reader to
creation of interactive material in Sage.  It's highly recommended that
you study the :doc:`Programming tutorial <Programming>` before tackling
this one.

Contents:

.. toctree::
   :maxdepth: 2

   Abstract Algebra <Quickstarts/Abstract-Algebra>
   Differential Equations <Quickstarts/Differential-Equations>
   Graph Theory/Discrete Math <Quickstarts/Graphs-and-Discrete>
   Linear Algebra <Quickstarts/Linear-Algebra>
   Multivariable Calculus <Quickstarts/Multivariable-Calculus>
   Numerical Analysis <Quickstarts/NumAnalysis>
   Number Theory/Cryptography <Quickstarts/Number-Theory>
   Statistics and Distributions <Quickstarts/Statistics-and-Distributions>
   Creating Interacts <Quickstarts/Interact>
